'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

// 1xx
const INFORMATIONAL = {
    100: '100 - Continue',
    101: '101 - Switching Protocols',
    102: '102 - Processing',
};
// 2xx
const SUCCESS = {
    200: '200 - OK',
    201: '201 - Created',
    202: '202 - Accepted',
    203: '203 - Non-authoritative Information',
    204: '204 - No Content',
    205: '205 - Reset Content',
    206: '206 - Partial Content',
    207: '207 - Multi-Status',
    208: '208 - Already Reported',
    209: '209 - IM Used',
};
// 3xx
const REDIRECTION = {
    300: '300 - Multiple Choices',
    301: '301 - Moved Permanently',
    302: '302 - Found',
    303: '303 - See Other',
    304: '304 - Not Modified',
    305: '305 - Use Proxy',
    307: '307 - Temporary Redirect',
    308: '308 - Permanent Redirect',
};
// 4xx
const CLIENT_ERROR = {
    400: '400 - Bad Request',
    401: '401 - Unauthorized',
    402: '402 - Payment Required',
    403: '403 - Forbidden',
    404: '404 - Not Found',
    405: '405 - Method Not Allowed',
    406: '406 - Not Acceptable',
    407: '407 - Proxy Authentication Required',
    408: '408 - Request Timeout',
    409: '409 - Conflict',
    410: '410 - Gone',
    411: '411 - Length Required',
    412: '412 - Precondition Failed',
    413: '413 - Payload Too Large',
    414: '414 - Request-URI Too Long',
    415: '415 - Unsupported Media Type',
    416: '416 - Requested Range Not Satisfiable',
    417: '417 - Expectation Failed',
    418: "418 - I'm a teapot",
    421: '421 - Misdirected Request',
    422: '422 - Unprocessable Entity',
    423: '423 - Locked',
    424: '424 - Failed Dependency',
    426: '426 - Upgrade Required',
    428: '428 - Precondition Required',
    429: '429 - Too Many Requests',
    431: '431 - Request Header Fields Too Large',
    444: '444 - Connection Closed Without Response',
    451: '451 - Unavailable For Legal Reasons',
    499: '499 - Client Closed Request',
};
// 5xx
const SERVER_ERROR = {
    500: '500 - Internal Server Error',
    501: '501 - Not Implemented',
    502: '502 - Bad Gateway',
    503: '503 - Service Unavailable',
    504: '504 - Gateway Timeout',
    505: '505 - HTTP Version Not Supported',
    506: '506 - Variant Also Negotiates',
    507: '507 - Insufficient Storage',
    508: '508 - Loop Detected',
    510: '510 - Not Extended',
    511: '511 - Network Authentication Required',
    599: '599 - Network Connect Timeout Error',
};
const HTTP_CODES = Object.assign(Object.assign(Object.assign(Object.assign(Object.assign({}, INFORMATIONAL), SUCCESS), REDIRECTION), CLIENT_ERROR), SERVER_ERROR);

/**
 * @function createModelMessage
 *
 * Assemble the default message header.
 *
 * @param code - HTTP status code 1xx to 5xx
 * @param title - Short and descriptive information
 */
const createModelMessage = ({ code, title, }) => {
    var model = { title: '', status: 0 };
    Object.entries(HTTP_CODES).filter(([_code, _title]) => {
        if (Number(_code) === code) {
            return (model = {
                status: Number(_code),
                title: title !== null && title !== void 0 ? title : _title.split(' - ')[1],
            });
        }
        return;
    });
    return model;
};

/**
 * @function createResponse
 *
 * Simple model for successful responses.
 *
 * @param code - HTTP status code 1xx to 3xx
 * @param ref - HTTP Code Reference
 * @param message - Legible action response
 * @param data - Back Data
 * @param title - Short and descriptive information
 */
const createResponse = ({ code = 200, message, data, title, }) => Object.assign(createModelMessage({ code, title }), { data, message });

/**
 * @function createError
 *
 * Creates an error response following the RFC 7807 pattern.
 *
 * @param code - HTTP status code 4xx to 5xx
 * @param ref - HTTP Code Reference
 * @param type - URL for a document describing the error condition
 * @param detail - Legible error description
 * @param instance - URI exclusive for or specific error
 * @param title - Short and descriptive information
 */
const createError = ({ code = 500, title, type = 'about:blank', detail, instance, }) => Object.assign(createModelMessage({ code, title }), { type, detail, instance });

/**
 * Default Server error
 */
const defaultError = createError({
    code: 500,
    detail: 'There was an internal server error.',
});

/**
 * @function handlerErrorKoa
 *
 * Koa Error handler
 *
 * @param ctx - Koa CTX object instance
 * @param error - Error object instance
 */
const handlerErrorKoa = ({ ctx, error }) => {
    error = (error === null || error === void 0 ? void 0 : error.status) ? error : defaultError;
    ctx.type = 'json';
    ctx.status = error.status;
    ctx.body = error;
    return ctx;
};

/**
 * @function handlerErrorExpress
 *
 * Express Error handler
 *
 * @param res - Express response object instance
 * @param error - Error object instance
 */
const handlerErrorExpress = ({ res, error }) => {
    error = (error === null || error === void 0 ? void 0 : error.status) ? error : defaultError;
    return res.status(error.status).json(error);
};

/**
 * @function handlerErrorAdonis
 *
 * Adonis Error handler
 *
 * @param response - Adonis response object instance
 * @param error - Error object instance
 */
const handlerErrorAdonis = ({ response, error }) => {
    error = (error === null || error === void 0 ? void 0 : error.status) ? error : defaultError;
    return response.status(error.status).json(error);
};

exports.createError = createError;
exports.createResponse = createResponse;
exports.handlerErrorAdonis = handlerErrorAdonis;
exports.handlerErrorExpress = handlerErrorExpress;
exports.handlerErrorKoa = handlerErrorKoa;
//# sourceMappingURL=index.js.map
